@@ -1,6 +1,6 @@
 pacotest = function(Udata,W,pacotestOptions, data = NULL, svcmDataFrame = NULL, cPitData = NULL){
   
-  if (is.character(pacotestOptions) && (is.element(pacotestOptions, c('CCC', 'ECORR', 'ECOV'))))
+  if (is.character(pacotestOptions) && (is.element(pacotestOptions, c('CCC', 'ECORR'))))
   {
     pacotestOptions = pacotestset(testType = pacotestOptions, withEstUncert = FALSE, estUncertWithRanks = FALSE)
   }
@@ -22,26 +22,23 @@ pacotest = function(Udata,W,pacotestOptions, data = NULL, svcmDataFrame = NULL,
   dimCondSet = dim(W)[2]
   
   # Prepare variables to be transfered to C++
-  if (pacotestOptions$testType=='ECOV' || pacotestOptions$testType=='CCC' || pacotestOptions$testType=='EC')
+  if (pacotestOptions$testType=='CCC' || pacotestOptions$testType=='EC')
   {
     # Add aggregated information to the conditioning vector
-    W = addAggInfo(W,pacotestOptions$aggInfo, pacotestOptions$sizeKeepingMethod)
+    W = addAggInfo(W,pacotestOptions$aggInfo)
     
     # Transfer (character) variables to numbers
     grouping = partitionToNumber(pacotestOptions$grouping)
-    testTypeNumber = testTypeToNumber(pacotestOptions$testType)
     
     finalComparison = finalComparisonToNumber(pacotestOptions$finalComparison)
     gamma0Partition = partitionToNumber(pacotestOptions$gamma0Partition)
     
-    aggPvalsNumbRep = aggPvalsNumbRepToNumber(pacotestOptions$aggPvalsNumbRep)
     expMinSampleSize = expMinSampleSizeToNumber(pacotestOptions$expMinSampleSize)
-    trainingDataFraction = trainingDataFractionToNumber(pacotestOptions$trainingDataFraction)
     penaltyParams = penaltyParamsToVector(pacotestOptions$penaltyParams)
     
   }
   
-  if (pacotestOptions$testType=='ECOV' || pacotestOptions$testType=='CCC')
+  if (pacotestOptions$testType=='CCC')
   {
     
     if (!(pacotestOptions$withEstUncert))
@@ -74,17 +71,17 @@ pacotest = function(Udata,W,pacotestOptions, data = NULL, svcmDataFrame = NULL,
       }
     }
     
-    out = ecorrOrEcov(testTypeNumber, as.matrix(Udata), as.matrix(W), dimCondSet,
-                      grouping, pacotestOptions$withEstUncert, pacotestOptions$estUncertWithRanks, finalComparison,
-                      as.matrix(data), svcmDataFrame, cPitData,
-                      aggPvalsNumbRep, expMinSampleSize, trainingDataFraction,
-                      penaltyParams[1], penaltyParams[2], gamma0Partition)
+    out = CCC(as.matrix(Udata), as.matrix(W), dimCondSet,
+              grouping, pacotestOptions$withEstUncert, pacotestOptions$estUncertWithRanks, finalComparison,
+              as.matrix(data), svcmDataFrame, cPitData,
+              expMinSampleSize,
+              penaltyParams[1], penaltyParams[2], gamma0Partition)
     
   }
   else if (pacotestOptions$testType=='EC')
   {
     out = EC(as.matrix(Udata), as.matrix(W), pacotestOptions$numbBoot,
-           grouping, finalComparison, expMinSampleSize, trainingDataFraction)
+           grouping, finalComparison, expMinSampleSize)
     
   }
   else if (pacotestOptions$testType=='VI')
@@ -97,7 +94,7 @@ pacotest = function(Udata,W,pacotestOptions, data = NULL, svcmDataFrame = NULL,
   }
   
   # Export/generate the decision tree and the illustrative plots
-  if (pacotestOptions$testType=='ECOV' || pacotestOptions$testType=='CCC' || pacotestOptions$testType=='EC')
+  if (pacotestOptions$testType=='CCC' || pacotestOptions$testType=='EC')
   {
     # Extract decision tree(s)
     if (grouping<=3)
@@ -150,13 +147,6 @@ partitionToNumber = function(partitionIdentifier)
   return(partitionNumber)
 }
 
-testTypeToNumber = function(partitionIdentifier)
-{
-  testTypeNumber = which(partitionIdentifier==c('ECOV', 'CCC', 'VI', 'EC'),arr.ind=TRUE)
-  
-  return(testTypeNumber)
-}
-
 finalComparisonToNumber = function(finalComparisonIdentifier = NULL)
 {
   if (is.null(finalComparisonIdentifier))
@@ -172,17 +162,6 @@ finalComparisonToNumber = function(finalComparisonIdentifier = NULL)
 }
 
 
-aggPvalsNumbRepToNumber = function(aggPvalsNumbRep = NULL)
-{
-  if (is.null(aggPvalsNumbRep) || aggPvalsNumbRep == 1)
-  {
-    aggPvalsNumbRep = 0
-  }
-  
-  return(aggPvalsNumbRep)
-}
-
-
 expMinSampleSizeToNumber = function(expMinSampleSize = NULL)
 {
   if (is.null(expMinSampleSize))
@@ -194,17 +173,6 @@ expMinSampleSizeToNumber = function(expMinSampleSize = NULL)
 }
 
 
-trainingDataFractionToNumber = function(trainingDataFraction = NULL)
-{
-  if (is.null(trainingDataFraction))
-  {
-    trainingDataFraction = NA_real_
-  }
-  
-  return(trainingDataFraction)
-}
-
-
 penaltyParamsToVector = function(penaltyParams = NULL)
 {
   if (is.null(penaltyParams))
